@@ -1,10 +1,7 @@
-//#![forbid(missing_docs)]
 //!
 //! Main module of this crate
 //!
 
-use regex::Regex;
-
 #[macro_use]
 extern crate lazy_static;
 
@@ -28,13 +25,15 @@ pub mod build;
 ///
 /// Basic grammar data structures and algorithms
 ///
+#[forbid(missing_docs)]
 pub mod grammar;
 
-pub use grammar::{Cfg, Pos, Pr, Rhs, Symbol, SymbolString, SymbolStrings, Terminal};
+pub use grammar::{Cfg, Pos, Pr, Rhs, Symbol, Terminal};
 
 ///
 /// Module with functionalities for grammar analysis
 ///
+#[forbid(missing_docs)]
 pub mod analysis;
 
 pub use analysis::{
@@ -45,6 +44,7 @@ pub use analysis::{
 ///
 /// Module with functionalities for grammar conversion
 ///
+#[forbid(missing_docs)]
 pub mod conversions;
 
 pub use conversions::{render_dfa_dot_string, render_nt_dot_string, render_par_string};
@@ -52,6 +52,7 @@ pub use conversions::{render_dfa_dot_string, render_nt_dot_string, render_par_st
 ///
 /// Module with functionalities for lexer and parser generation
 ///
+#[forbid(missing_docs)]
 pub mod generators;
 pub use generators::{
     check_and_transform_grammar, generate_lexer_source, generate_parser_source,
@@ -64,9 +65,11 @@ pub use parser::{parse, ParolGrammar};
 ///
 /// Module with functionalities for grammar transformation
 ///
+#[forbid(missing_docs)]
 pub mod transformation;
 pub use transformation::left_factor;
 
+#[forbid(missing_docs)]
 mod utils;
 pub use utils::{generate_tree_layout, obtain_grammar_config};
 
@@ -77,10 +80,3 @@ pub(crate) use utils::{generate_name, group_by};
 /// Internal lookahead limit
 ///
 pub const MAX_K: usize = 10;
-
-lazy_static! {
-    ///
-    /// Regex used for portable newline handling
-    pub static ref RX_NEWLINE: Regex =
-        Regex::new(r"\r\n|\r\n").expect("error parsing regex");
-}
